@@ -12,10 +12,11 @@ from logging import StreamHandler
 from logging.handlers import TimedRotatingFileHandler
 from pathlib import Path
 
-from mxcubecore import ColorFormatter
+from mxcubecore import (
+    ColorFormatter,
+)
 from mxcubecore import HardwareRepository as HWR
 from mxcubecore import (
-    queue_entry,
     removeLoggingHandlers,
 )
 from mxcubecore.utils.conversion import make_table
@@ -111,6 +112,7 @@ class MXCUBECore:
     def _get_object_from_id(_id):
         if _id in MXCUBECore.adapter_dict:
             return MXCUBECore.adapter_dict[_id]["adapter"]
+        return None
 
     @staticmethod
     def _get_adapter_id(ho):
@@ -138,7 +140,7 @@ class MXCUBECore:
 
     @staticmethod
     def adapt_hardware_objects(app):
-        hwobject_list = [item for item in MXCUBECore.hwr.hardware_objects]
+        hwobject_list = list(MXCUBECore.hwr.hardware_objects)
 
         for ho_name in hwobject_list:
             # Go through all hardware objects exposed by mxcubecore
@@ -214,7 +216,7 @@ class MXCUBEApplication:
     VIDEO_FORMAT = "MPEG1"
 
     # Contains the complete client side ui state, managed up state_storage.py
-    UI_STATE = dict()
+    UI_STATE = {}
     TEMP_DISABLED = []
 
     # Below variables used for application wide settings
@@ -247,9 +249,8 @@ class MXCUBEApplication:
     server = None
 
     def __init__(self):
-        raise NotImplementedError(
-            "MXCUBEApplication is to be used as a pure static class, dont instanciate"
-        )
+        msg = "MXCUBEApplication is to be used as a pure static class, dont instanciate"
+        raise NotImplementedError(msg)
 
     @staticmethod
     def init(
@@ -395,10 +396,7 @@ class MXCUBEApplication:
             )
             uilog_file_handler.setFormatter(file_formatter)
 
-        if not log_level:
-            log_level = "INFO"
-        else:
-            log_level = log_level.upper()
+        log_level = "INFO" if not log_level else log_level.upper()
 
         custom_log_handler = MX3LoggingHandler(MXCUBEApplication.server)
         custom_log_handler.setLevel(log_level)
