@@ -18,7 +18,7 @@ class ActuatorAdapter(ActuatorAdapterBase):
         Args:
             (object): Hardware object.
         """
-        super(ActuatorAdapter, self).__init__(ho, *args)
+        super().__init__(ho, *args)
         self._event_rate = 4
 
         @RateLimited(self._event_rate)
@@ -60,9 +60,10 @@ class ActuatorAdapter(ActuatorAdapterBase):
             ValueError: When value for any reason can't be retrieved.
         """
         try:
-            return FloatValueModel(**{"value": self._ho.get_value()})
+            return FloatValueModel(value=self._ho.get_value())
         except (AttributeError, TypeError):
-            raise ValueError("Could not get value")
+            msg = "Could not get value"
+            raise ValueError(msg)
 
     def stop(self):
         """
