@@ -15,23 +15,21 @@ class NStateAdapter(ActuatorAdapterBase):
         Args:
             (object): Hardware object.
         """
-        super(NStateAdapter, self).__init__(ho, *args)
+        super().__init__(ho, *args)
         self._value_change_model = HOActuatorValueChangeModel
 
         ho.connect("valueChanged", self._value_change)
         ho.connect("stateChanged", self.state_change)
 
     def _value_change(self, value):
-        if isinstance(value, Enum):
-            v = value.name
-        else:
-            v = value
+        v = value.name if isinstance(value, Enum) else value
 
         self.value_change(v)
 
     def _get_valid_states(self):
         state_names = [v.name for v in self._ho.VALUES]
-        state_names.remove("UNKNOWN")
+        if "UNKNOWN" in state_names:
+            state_names.remove("UNKNOWN")
 
         return state_names
 
@@ -48,7 +46,7 @@ class NStateAdapter(ActuatorAdapterBase):
         self._ho.set_value(self._ho.VALUES[value.value])
 
     def _get_value(self) -> StrValueModel:
-        return StrValueModel(**{"value": self._ho.get_value().name})
+        return StrValueModel(value=self._ho.get_value().name)
 
     def msg(self):
         try:
