@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import logging
 
 from mxcubecore import HardwareRepository as HWR
@@ -138,7 +137,7 @@ class Beamline(ComponentBase):
     def beamline_get_all_attributes(self):
         ho = BeamlineAdapter(HWR.beamline)
         data = ho.dict()
-        actions = list()
+        actions = []
 
         try:
             cmds = HWR.beamline.beamline_actions.get_commands()
@@ -190,7 +189,7 @@ class Beamline(ComponentBase):
         beamline_actions = HWR.beamline.beamline_actions
 
         if getattr(beamline_actions, "pydantic_model", None):
-            for cmd_name in beamline_actions.exported_attributes.keys():
+            for cmd_name in beamline_actions.exported_attributes:
                 cmd_object = beamline_actions.get_annotated_command(cmd_name)
 
                 actions.append(
@@ -290,7 +289,7 @@ class Beamline(ComponentBase):
 
     def diffractometer_set_phase(self, phase):
         try:
-            HWR.beamline.diffractometer.wait_device_ready(30)
+            HWR.beamline.diffractometer.wait_ready(30)
         except Exception:
             logging.getLogger("MX3.HWR").warning("Diffractometer not ready")
 
