@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-import json
 import logging
 import math
 import re
@@ -11,7 +9,6 @@ from mxcubecore.model import queue_model_objects as qmo
 from mxcubecore.model.lims_session import LimsSessionManager
 
 from mxcubeweb.core.components.component_base import ComponentBase
-from mxcubeweb.core.util import fsutils
 
 VALID_SAMPLE_NAME_REGEXP = re.compile("^[a-zA-Z0-9:+_-]+$")
 
@@ -167,7 +164,7 @@ class Lims(ComponentBase):
         return prefix
 
     def get_session_manager(self) -> LimsSessionManager:
-        return LimsSessionManager.parse_obj(json.loads(current_user.limsdata))
+        return HWR.beamline.lims.session_manager
 
     def is_rescheduled_session(self, session):
         """
@@ -184,11 +181,9 @@ class Lims(ComponentBase):
         param session_id : this is a identifier that could be proposal name or session_id depending of the type of LIMS login type
         """
         logging.getLogger("MX3.HWR").debug("select_session session_id=%s" % session_id)
-        session = None
 
         # Selecting the active session in the LIMS object
         try:
-            HWR.beamline.lims.set_active_session_by_id(session_id)
             session = HWR.beamline.lims.set_active_session_by_id(session_id)
             if session is None:
                 raise "No session selected on LIMS"
@@ -202,18 +197,38 @@ class Lims(ComponentBase):
             self.app.usermanager.signout()
             return False
 
-        if HWR.beamline.lims.is_user_login_type() and "Commissioning" in session.title:
-            if hasattr(HWR.beamline.session, "set_in_commissioning"):
-                HWR.beamline.session.set_in_commissioning(self.get_proposal_info())
-                logging.getLogger("MX3.HWR").info(
-                    "[LIMS] Commissioning proposal flag set."
-                )
+        if (
+            HWR.beamline.lims.is_user_login_type()
+            and "Commissioning" in session.title
+            and hasattr(HWR.beamline.session, "set_in_commissioning")
+        ):
+            HWR.beamline.session.set_in_commissioning(self.get_proposal_info())
+            logging.getLogger("MX3.HWR").info("[LIMS] Commissioning proposal flag set.")
 
-        HWR.beamline.session.proposal_code = session.code
-        HWR.beamline.session.proposal_number = session.number
-        HWR.beamline.session.session_id = HWR.beamline.lims.get_session_id()
-        HWR.beamline.session.proposal_id = session.proposal_id
-        HWR.beamline.session.set_session_start_date(session.start_date)
+        if HWR.beamline.session.session_id != HWR.beamline.lims.get_session_id():
+            # ruff: noqa: G004
+            logging.getLogger("MX3.HWR").info(
+                f"[LIMS] New session, clearing queue and sample list for {session.code}{session.number}"
+            )
+
+            # Clear data collection queue (HardwareObject)
+            self.app.queue.clear_queue()
+
+            # Remove any items on the sample view (shapes)
+            HWR.beamline.sample_view.clear_all()
+
+            # Re-initialize the samplelist
+            self.app.lims.init_sample_list()
+
+            # Get sample list and send update to client
+            self.app.sample_changer.get_sample_list()
+            self.app.server.emit("update_queue", {}, namespace="/hwr")
+
+            HWR.beamline.session.proposal_code = session.code
+            HWR.beamline.session.proposal_number = session.number
+            HWR.beamline.session.session_id = HWR.beamline.lims.get_session_id()
+            HWR.beamline.session.proposal_id = session.proposal_id
+            HWR.beamline.session.set_session_start_date(session.start_date)
 
         logging.getLogger("MX3.HWR").info(
             "[LIMS] Selected session. proposal=%s session_id=%s.",
@@ -234,14 +249,12 @@ class Lims(ComponentBase):
                     session.number,
                 )
                 raise "To be implemented for those using prepare_directories"
-                # HWR.beamline.session.prepare_directories(proposal_tuple)
             except Exception:
                 logging.getLogger("MX3.HWR").info(
                     "[LIMS] Error creating data directories, %s" % sys.exc_info()[1]
                 )
 
         # save selected proposal in users db
-
         current_user.selected_proposal = session.session_id
         self.app.usermanager.update_user(current_user)
 
@@ -268,8 +281,8 @@ class Lims(ComponentBase):
         return HWR.beamline.session.get_default_subdir(sample_data)
 
     def synch_with_lims(self, lims_name):
-        # session_id is not used, so we can pass None as second argument to
-        # 'db_connection.get_samples'
+        self.app.queue.queue_clear()
+        self.app.sample_changer.get_sample_list()
 
         samples_info_list = HWR.beamline.lims.get_samples(lims_name)
         for sample_info in samples_info_list:
