@@ -1,7 +1,5 @@
-import atexit
 import logging
 import os
-import signal
 import traceback
 
 import flask_security
@@ -37,9 +35,8 @@ class Server:
     flask_socketio = None
 
     def __init__(self):
-        raise NotImplementedError(
-            "Server is to be used as a pure static class, don't instantiate."
-        )
+        msg = "Server is to be used as a pure static class, don't instantiate."
+        raise NotImplementedError(msg)
 
     @staticmethod
     def exception_handler(e):
@@ -47,23 +44,6 @@ class Server:
         logging.getLogger("exceptions").exception(err_msg)
         return err_msg + ": " + traceback.format_exc(), 409
 
-    @staticmethod
-    def kill_processes():
-        # Killing the processes causes pytest to fail because
-        # of non-zero exit code, so we don't kill the processes
-        # when running the tests
-        if not Server.flask.testing:
-            with open("/tmp/mxcube.pid", "r") as f:
-                pid_list = f.read().strip()
-                pid_list = pid_list.split(" ")
-                pid_list.reverse()
-
-            with open("/tmp/mxcube.pid", "w") as f:
-                f.write("")
-
-            for pid in pid_list:
-                os.kill(int(pid), signal.SIGKILL)
-
     @staticmethod
     def init(cmdline_options, cfg):
         template_dir = os.path.join(os.path.dirname(__file__), "templates")
@@ -103,11 +83,6 @@ class Server:
         # the following test prevents Flask from initializing twice
         # (because of the Reloader)
         if not Server.flask.debug or os.environ.get("WERKZEUG_RUN_MAIN") == "true":
-            atexit.register(Server.kill_processes)
-
-            with open("/tmp/mxcube.pid", "w") as f:
-                f.write(str(os.getpid()) + " ")
-
             # Make the valid_login_only decorator available on server object
             Server.restrict = staticmethod(networkutils.auth_required)
             Server.require_control = staticmethod(networkutils.require_control)
@@ -120,9 +95,8 @@ class Server:
         Server.flask.register_blueprint(bp)
 
         for key, function in Server.flask.view_functions.items():
-            if key.startswith(bp.name):
-                if not hasattr(function, "tags"):
-                    function.tags = [bp.name.title().replace("_", " ")]
+            if key.startswith(bp.name) and not hasattr(function, "tags"):
+                function.tags = [bp.name.title().replace("_", " ")]
 
     @staticmethod
     def register_routes(mxcube):
